"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomerCarrierCredentialsQuery = void 0;
const qs_1 = require("qs");
const exceptions_1 = require("../exceptions");
class CustomerCarrierCredentialsQuery {
    async processQuery(requestModel, client) {
        var _a, _b, _c, _d, _e, _f;
        const { customerId, carrier } = requestModel;
        const response = await client.get(`api/customers?${this.createCustomerCredentialsQuery(customerId, carrier)}`);
        if (response.data.meta.pagination.total === 0)
            return null;
        if (response.data.data.some((customer) => customer.attributes.credentials.data.length > 1))
            throw new exceptions_1.UniqueViolationException(`Customer ${customerId} has defined multiple ${carrier} credentials`);
        const carrierCredentials = (_f = (_e = (_d = (_c = (_b = (_a = response.data) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b[0]) === null || _c === void 0 ? void 0 : _c.attributes) === null || _d === void 0 ? void 0 : _d.credentials) === null || _e === void 0 ? void 0 : _e.data) === null || _f === void 0 ? void 0 : _f.find((credential) => credential.attributes.carriers.data[0].attributes.carrierID === carrier.toLocaleUpperCase());
        if (!carrierCredentials)
            throw new exceptions_1.InvalidCarrierCredentialsException(`Customer ${customerId} doesn't have access to ${carrier}`);
        const { clientNumber, username, password } = carrierCredentials.attributes;
        return {
            clientNumber,
            password,
            username,
        };
    }
    createCustomerCredentialsQuery(customerId, carrier) {
        return (0, qs_1.stringify)({
            populate: {
                credentials: {
                    populate: ['carriers'],
                    filters: {
                        carriers: {
                            carrierID: {
                                $eq: carrier,
                            },
                        },
                    },
                },
            },
            filters: {
                customerID: {
                    $eq: customerId,
                },
                credentials: {
                    carriers: {
                        carrierID: {
                            $eq: carrier,
                        },
                    },
                },
            },
        }, {
            encodeValuesOnly: true,
        });
    }
}
exports.CustomerCarrierCredentialsQuery = CustomerCarrierCredentialsQuery;
//# sourceMappingURL=customerCarrierCredentials.query.js.map